@@ -43,7 +43,7 @@ void FolderPlugin::registerTypes(const char *uri)
     qmlRegisterType<ItemViewAdapter>(uri, 0, 1, "ItemViewAdapter");
     qmlRegisterType<LabelGenerator>(uri, 0, 1, "LabelGenerator");
     qmlRegisterType<MenuHelper>(uri, 0, 1, "MenuHelper");
-    qmlRegisterType<FilterableMimeTypesModel>(uri, 0, 1, "FilterableMimeTypesModel");
+    qmlRegisterType<MimeTypesModel>(uri, 0, 1, "MimeTypesModel");
     qmlRegisterType<PlacesModel>(uri, 0, 1, "PlacesModel");
     qmlRegisterType<Positioner>(uri, 0, 1, "Positioner");
     qmlRegisterType<PreviewPluginsModel>(uri, 0, 1, "PreviewPluginsModel");
