@@ -37,12 +37,12 @@ class MimeTypesModel : public QAbstractListModel
         ~MimeTypesModel();
 
         QHash<int, QByteArray> roleNames() const override;
-        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+        bool setData(const QModelIndex &index, const QVariant &value, int role) Q_DECL_OVERRIDE;
 
         Q_INVOKABLE void checkAll();
-        Q_INVOKABLE void setRowChecked(int row, bool checked);
 
-        int rowCount(const QModelIndex &parent = QModelIndex()) const { Q_UNUSED(parent) return m_mimeTypesList.size(); }
+        int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE { Q_UNUSED(parent) return m_mimeTypesList.size(); }
 
         QStringList checkedTypes() const;
         void setCheckedTypes(const QStringList &list);
@@ -57,33 +57,4 @@ class MimeTypesModel : public QAbstractListModel
         QVector<bool> checkedRows;
 };
 
-class FilterableMimeTypesModel : public QSortFilterProxyModel
-{
-    Q_OBJECT
-
-    Q_PROPERTY(QStringList checkedTypes READ checkedTypes WRITE setCheckedTypes NOTIFY checkedTypesChanged)
-    Q_PROPERTY(QString filter READ filter WRITE setFilter NOTIFY filterChanged)
-
-    public:
-        FilterableMimeTypesModel(QObject *parent = 0);
-        ~FilterableMimeTypesModel();
-
-        Q_INVOKABLE void setRowChecked(int row, bool checked);
-        Q_INVOKABLE void checkAll();
-
-        QStringList checkedTypes() const;
-        void setCheckedTypes(const QStringList &list);
-
-        QString filter() const;
-        void setFilter(const QString &filter);
-
-    Q_SIGNALS:
-        void checkedTypesChanged() const;
-        void filterChanged() const;
-
-    private:
-        MimeTypesModel *m_sourceModel;
-        QString m_filter;
-};
-
 #endif
