@@ -32,11 +32,6 @@ PlacesModel::PlacesModel(QObject *parent) : QSortFilterProxyModel(parent)
 
     setSourceModel(m_sourceModel);
 
-    QHash<int, QByteArray> roleNames = m_sourceModel->roleNames();
-    roleNames[Qt::DisplayRole] = "display";
-    roleNames[Qt::DecorationRole] = "decoration";
-    setRoleNames(roleNames);
-
     setDynamicSortFilter(true);
 }
 
@@ -44,6 +39,14 @@ PlacesModel::~PlacesModel()
 {
 }
 
+QHash<int, QByteArray> PlacesModel::roleNames() const
+{
+    QHash<int, QByteArray> roleNames = QSortFilterProxyModel::roleNames();
+    roleNames[Qt::DisplayRole] = "display";
+    roleNames[Qt::DecorationRole] = "decoration";
+    return roleNames;
+}
+
 bool PlacesModel::activityLinkingEnabled()
 {
     const KService::List services = KServiceTypeTrader::self()->query(QStringLiteral("KFileItemAction/Plugin"),
